import pathlib

from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    version="0.0.7",
    name="matsim-tools",
    description="MATSim Agent-Based Transportation Simulation Framework - official python analysis tools",
    long_description_content_type='text/markdown',
    url="https://github.com/matsim-vsp/matsim-python-tools",
    author="VSP-Berlin",
    author_email="laudan@tu-berlin.de",
    license="GPLv3",
    classifiers=[
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Programming Language :: Python :: 3",
    ],
    packages=["matsim"],
    install_requires=[
        "protobuf >= 3.10.0",
        "xopen",
        "pandas", # "shapely", "geopandas >= 0.6.0"
    ],
    tests_require=[
        "assertpy",
        "pytest"
    ],
    entry_points={},
    long_description=README,
)



import xopen
import xml.etree.ElementTree as ET

def plan_reader(filename, selectedPlansOnly = False):

    person = None
    tree = ET.iterparse(xopen.xopen(filename), events=['start','end'])

    for xml_event, elem in tree:
        
        if elem.tag == 'person' and xml_event == 'start':
            # keep track of whether a person node has any plans
            this_person_has_plans = False

            if person: person.clear() # clear memory
            person = elem

        elif elem.tag == 'plan' and xml_event == 'end':
            this_person_has_plans = True

            # filter out unselected plans if asked to do so
            if selectedPlansOnly and elem.attrib['selected'] == 'no': continue

            yield (person, elem)

            # free memory. Otherwise the data is kept in memory
            elem.clear()
        
        elif elem.tag == 'person' and xml_event == 'end':
            # if this person has no plans, then yield the person with a None plan.
            if not this_person_has_plans:
                yield (person, None)

